<?php

/**
 * @author Jaap Jansma (CiviCooP) <jaap.jansma@civicoop.org>
 * @license http://www.gnu.org/licenses/agpl-3.0.html
 */

 namespace Civi\FormProcessor\Type;

 use CRM_FormProcessor_ExtensionUtil as E;

 class Factory {

	/**
	 * @var array<AbstractType>
	 */
	protected $types = array();

	public function __construct() {
		$this->addType(new GenericType('Integer', E::ts('Numeric (no-decimal)')));
		$this->addType(new GenericType('Float', E::ts('Numeric (with-decimal)')));
		$this->addType(new FormattedDecimalType(E::ts('Formatted decimal number')));
		$this->addType(new GenericType('String', E::ts('Short text')));
		$this->addType(new GenericType('Text', E::ts('Long text')));
		$this->addType(new DateType(E::ts('Date')));
    $this->addType(new TimeType(E::ts('Time')));
		$this->addType(new GenericType('Boolean', E::ts('Yes/No')));
    $this->addType(new YesNoOptionListType('YesNoOptionList', E::ts('Yes/No as Option List')));
    $this->addType(new OptionGroupType('OptionGroup', E::ts('Option Group')));
    $this->addType(new CustomOptionListType('CustomOptionListType', E::ts('Custom Options')));
    $this->addType(new CountryType('Country', E::ts('Country')));
    $this->addType(new CountryIsoCodeType('CountryIsoCode', E::ts('Country ISO Code')));
    $this->addType(new StateProvinceType('StateProvince', E::ts('State/Province')));
    $this->addType(new MailingGroupType('MailingGroup', E::ts('Mailing Group')));
    $this->addType(new ParentMailingGroupType('ParentMailingGroup', E::ts('Parent Mailing Group')));
    $this->addType(new ParticipantStatusType('ParticipantStatusType', E::ts('Participant Status')));
    $this->addType(new CampaignType('CampaignType', E::ts('Campaign')));
    $this->addType(new FinancialTypeType('FinancialTypeType', E::ts('Financial Type')));
    $this->addType(new MembershipTypeType('MembershipTypeType', E::ts('Membership Type')));
    $this->addType(new FileType('file', E::ts('File')));
    $this->addType(new WeekDays('WeekDays', E::ts('Week Days')));
	}

	/**
	 * Add a type
	 *
	 * @param AbstractType $type
	 */
	public function addType(AbstractType $type) {
		$this->types[$type->getName()] = $type;
		return $this;
	}

	/**
	 * Return the type
	 *
	 * @param string $name
	 * @return AbstractType|null
	 */
	public function getTypeByName($name) {
		if (isset($this->types[$name])) {
		  $type = clone $this->types[$name];
      $type->setDefaults();
      return $type;
		}
		return null;
	}

	/**
	 * @return array<AbstractType>
	 */
	public function getTypes() {
		return $this->types;
	}

 }
