<?php

/**
 * @author Jaap Jansma (CiviCooP) <jaap.jansma@civicoop.org>
 * @license http://www.gnu.org/licenses/agpl-3.0.html
 */
 
 namespace Civi\FormProcessor\Type;

 use \Civi\FormProcessor\Config\Specification;
 use \Civi\FormProcessor\Config\SpecificationBag;
 use \Civi\FormProcessor\Type\AbstractType;
 use \Civi\FormProcessor\Type\OptionListInterface;

 use \CRM_FormProcessor_ExtensionUtil as E;
 
 class ParticipantStatusType extends AbstractType implements OptionListInterface {

   /**
    * Get the configuration specification
    *
    * @return SpecificationBag
    */
   public function getConfigurationSpecification() {
     return new SpecificationBag(array(
       new Specification('multiple', 'Boolean', E::ts('Multiple'), false, 0, null, array(0=>E::ts('Single value'), 1=>E::ts('Multiple values'))),
     ));
   }
   
     
  public function validateValue($value, $allValues=array()) {
    $multiple = $this->configuration->get('multiple') ? true : false;
    $options = $this->getOptions();

    if ($multiple && is_array($value)) {
      foreach ($value as $valueItem) {
        if (\CRM_Utils_Type::validate($valueItem, 'Integer', FALSE) === NULL) {
          return FALSE;
        }
        if (!isset($options[$valueItem])) {
          return FALSE;
        }
      }
    } elseif (!is_array($value)) {
      if (\CRM_Utils_Type::validate($value, 'Integer', FALSE) === NULL) {
        return FALSE;
      }
      if (!isset($options[$value])) {
        return FALSE;
      }
    } else {
      return FALSE;
    }
    return true;
  }
  
  /**
   * Returns the type number from CRM_Utils_Type
   */
  public function getCrmType() {
    return \CRM_Utils_Type::T_INT;
  }
  
  public function getOptions($params) {
    static $return;
    if ($return) {
      return $return;
    }
    $groups = civicrm_api3('ParticipantStatusType', 'get', array('is_active'  => 1, 'options'=>array('limit'=>0)));
    $return = array();
    foreach($groups['values'] as $group) {
      $return[$group['id']] = $group['label'];
    }
    return $return;
  }
   
 }