<?php

/**
 * @author Jaap Jansma (CiviCooP) <jaap.jansma@civicoop.org>
 * @license http://www.gnu.org/licenses/agpl-3.0.html
 */

namespace Civi\FormProcessor\Type;

use \Civi\FormProcessor\Config\Specification;
use \Civi\FormProcessor\Config\SpecificationBag;

use \CRM_FormProcessor_ExtensionUtil as E;

class WeekDays extends AbstractType implements OptionListInterface {

  /**
   * Get the configuration specification
   *
   * @return SpecificationBag
   */
  public function getConfigurationSpecification() {
    return new SpecificationBag(array(
      new Specification('multiple', 'Boolean', E::ts('Multiple'), false, 0, null, array(0=>E::ts('Single value'), 1=>E::ts('Multiple values'))),
    ));
  }

  public function validateValue($value, $allValues=array()) {
    $multiple = $this->configuration->get('multiple') ? true : false;
    $options = $this->getOptions();
    if ($multiple && is_array($value)) {
      foreach ($value as $valueItem) {
        if (\CRM_Utils_Type::validate($valueItem, 'String', FALSE) === NULL) {
          return FALSE;
        }
        if (!isset($options[$valueItem])) {
          return FALSE;
        }
      }
    } elseif (!is_array($value) && $value) {
      if (\CRM_Utils_Type::validate($value, 'String', FALSE) === NULL) {
        return FALSE;
      }

      if (!isset($options[$value])) {
        return false;
      }
    } else {
      return false;
    }

    return true;
  }

  /**
   * Returns the type number from CRM_Utils_Type
   */
  public function getCrmType() {
    return \CRM_Utils_Type::T_STRING;
  }

  public function getOptions($params) {
    $options = array(
      'sunday' => E::ts('Sunday'),
      'monday' => E::ts('Monday'),
      'tuesday' => E::ts('Tuesday'),
      'wednesday' => E::ts('Wednesday'),
      'thursday' => E::ts('Thursday'),
      'friday' => E::ts('Friday'),
      'saturday' => E::ts('Saturday'),
    );

    return $options;
  }

}
