<?php

/**
 * @author Jaap Jansma (CiviCooP) <jaap.jansma@civicoop.org>
 * @license http://www.gnu.org/licenses/agpl-3.0.html
 */

namespace Civi\FormProcessor\Type;

use \Civi\FormProcessor\Config\Specification;
use \Civi\FormProcessor\Config\SpecificationBag;
use \Civi\FormProcessor\Type\AbstractType;
use \Civi\FormProcessor\Type\OptionListInterface;

use \CRM_FormProcessor_ExtensionUtil as E;

class YesNoOptionListType extends AbstractType implements OptionListInterface {

  private $options;

  private $optionsLoaded = false;

  /**
   * Get the configuration specification
   *
   * @return SpecificationBag
   */
  public function getConfigurationSpecification() {
    return new SpecificationBag(array(
      new Specification('yes_label', 'String', E::ts('Yes label'), true, E::ts('Yes'), null, null, false),
      new Specification('no_label', 'String', E::ts('No label'), true, E::ts('No'), null, null, false),
    ));
  }

  public function validateValue($value, $allValues=array()) {
    return true;
  }

  /**
   * Returns the type number from CRM_Utils_Type
   */
  public function getCrmType() {
    return \CRM_Utils_Type::T_BOOLEAN;
  }

  public function getOptions($params) {
    $this->loadOptions();
    return $this->options;
  }

  /**
   * Normalize the input value.
   *
   * @param $value
   *
   * @return mixed
   */
  public function normalizeValue($value) {
    return $value ? '1': '0';
  }

  /**
   * Denormalize the input value.
   *
   * @param $value
   *
   * @return mixed
   */
  public function denormalizeValue($value) {
    return $value ? '1': '0';
  }

  private function loadOptions() {
    if ($this->optionsLoaded) {
      return;
    }

    $yes_label = $this->configuration->get('yes_label') ? $this->configuration->get('yes_label') : E::ts('Yes');
    $no_label = $this->configuration->get('no_label') ? $this->configuration->get('no_label') : E::ts('No');
    $this->options = array(
      '1' => $yes_label,
      '0' => $no_label,
    );
    $this->optionsLoaded = true;

    return $this->options;
  }

  /**
   * Sets the default values of this action
   */
  public function setDefaults() {
    parent::setDefaults();
    $this->options = null;
    $this->optionsLoaded = false;
  }

}
