<?php
/**
 * @author Jaap Jansma <jaap.jansma@civicoop.org>
 * @license AGPL-3.0
 */

namespace Civi\FormProcessor\Utils;

class Cache {

  /**
   * @param $key
   * @param null|mixed $default
   *
   * @return mixed
   * @throws \CRM_Core_Exception
   */
  public static function get($key, $default=null) {
    $cache = self::getCacheClass();
    return $cache->get($key, $default);
  }

  /**
   * Set the value in the cache.
   *
   * @param string $key
   * @param mixed $value
   * @param null|int|\DateInterval $ttl
   * @return bool
   * @throws \CRM_Core_Exception
   */
  public static function set($key, $value, $ttl=null) {
    $cache = self::getCacheClass();
    return $cache->set($key, $value, $ttl);
  }

  /**
   * Delete all values from the cache.
   *
   * NOTE: flush() and clear() should be aliases. flush() is specified by
   * Civi's traditional interface, and clear() is specified by PSR-16.
   *
   * @return bool
   * @see flush
   * @throws \CRM_Core_Exception
   */
  public static function clear() {
    $cache = self::getCacheClass();
    return $cache->clear();
  }

  /**
   * @return \CRM_Utils_Cache_Interface
   * @throws \CRM_Core_Exception
   */
  public static function getCacheClass() {
    $cache = \CRM_Utils_Cache::create([
      'name' => 'formprocessor',
      'type' => ['*memory*', 'SqlGroup', 'ArrayCache'],
      'prefetch' => true,
    ]);
    return $cache;
  }

}
