<?php
/**
 * FormProcessorInstance.Get API
 *
 * @param array $params
 * @return array API result descriptor
 * @see civicrm_api3_create_success
 * @see civicrm_api3_create_error
 * @throws API_Exception
 */
function civicrm_api3_form_processor_instance_get($params) {
  $returnValues = CRM_FormProcessor_BAO_FormProcessorInstance::getValues($params);
	foreach($returnValues as $index => $formProcessor) {
		// Convert inputs to arrays	
		foreach($formProcessor['inputs'] as $key => $input) {
			$returnValues[$index]['inputs'][$key]['type'] = $input['type']->toArray();
			foreach($input['validators'] as $validator_key => $validator) {
				$returnValues[$index]['inputs'][$key]['validators'][$validator_key]['validator'] = $validator['validator']->toArray();
			}
		}
		
		// Convert inputs to arrays	
		foreach($formProcessor['default_data_inputs'] as $key => $input) {
			$returnValues[$index]['default_data_inputs'][$key]['type'] = $input['type']->toArray();
			foreach($input['validators'] as $validator_key => $validator) {
				$returnValues[$index]['default_data_inputs'][$key]['validators'][$validator_key]['validator'] = $validator['validator']->toArray();
			}
		}
		
		// Convert output handler object to array
		$returnValues[$index]['output_handler'] = $returnValues[$index]['output_handler']->toArray();
	}
  return civicrm_api3_create_success($returnValues, $params, 'FormProcessorInstance', 'Get');
}

/**
 * FormProcessorInstance.Get API specification (optional)
 * This is used for documentation and validation.
 *
 * @param array $spec description of fields supported by this API call
 * @return void
 * @see http://wiki.civicrm.org/confluence/display/CRM/API+Architecture+Standards
 */
function _civicrm_api3_form_processor_instance_get_spec(&$spec) {
	$fields = CRM_FormProcessor_BAO_FormProcessorInstance::fields();
	foreach($fields as $fieldname => $field) {
		$spec[$fieldname] = $field;
	}
}

