<?php
use CRM_FormProcessor_ExtensionUtil as E;

/**
 * FormProcessorInstance.Import API specification (optional)
 * This is used for documentation and validation.
 *
 * @param array $spec description of fields supported by this API call
 * @return void
 * @see http://wiki.civicrm.org/confluence/display/CRMDOC/API+Architecture+Standards
 */
function _civicrm_api3_form_processor_instance_Import_spec(&$spec) {
  $spec['file'] = array(
    'title' => E::ts('Specification File'),
    'type' => CRM_Utils_Type::T_STRING,
    'description' => E::ts('If a file path is given, the JSON configuration will be imported from there'),
    'api.required' => false
  );
}

/**
 * FormProcessorInstance.Import API
 *
 * @param array $params
 * @return array API result descriptor
 * @see civicrm_api3_create_success
 * @see civicrm_api3_create_error
 * @throws API_Exception
 */
function civicrm_api3_form_processor_instance_Import($params) {
  $exporter = new \Civi\FormProcessor\Exporter\ExportToJson();
  $returnValues = array();

  if (empty($params['file'])) {
    // default behaviour
    $returnValues['import'] = $exporter->importFromExtensions();
    // Clear the cache
    \Civi\FormProcessor\Utils\Cache::clear();
    $returnValues['is_error'] = 0;

  } else {
    // caller provided a file to import:
    $data = json_decode(file_get_contents($params['file']), true);
    if (!empty($data['name'])) {
      $status = \CRM_FormProcessor_BAO_FormProcessorInstance::getStatus($data['name']);
      if ($status != \CRM_FormProcessor_Status::IN_CODE) {
        // it's already overridden -> reset so we can override again
        \CRM_FormProcessor_BAO_FormProcessorInstance::setStatus($data['name'], \CRM_FormProcessor_Status::IN_CODE);
      }
      $returnValues['import'] = $exporter->import($data, $params['file']);
      $returnValues['import']['original_status'] = $status; // we might have adjusted it, so we know better
      // Clear the cache
      \Civi\FormProcessor\Utils\Cache::clear();
      $returnValues['is_error'] = 0;

    } else {
      $returnValues = civicrm_api3_create_error("The file '{$params['file']}' doesn't contain a form processor specification.");
    }
  }
  return $returnValues;
}
